@@ -13,11 +13,7 @@ from typing import (
     Any,
     Callable,
     ClassVar,
-    Dict,
-    List,
     Optional,
-    Set,
-    Tuple,
     TypeVar,
     Union,
     cast,
@@ -27,16 +23,20 @@ from xml.dom.minidom import parseString as parseXML
 
 import boto3
 import requests
-from botocore.model import OperationModel, ServiceModel
 from jinja2 import DictLoader, Environment, Template
 from werkzeug.exceptions import HTTPException
 
 from moto import settings
 from moto.core.common_types import TYPE_IF_NONE, TYPE_RESPONSE
 from moto.core.exceptions import DryRunClientError, ServiceException
-from moto.core.parsers import PROTOCOL_PARSERS, XFormedDict
+from moto.core.model import OperationModel, ServiceModel
+from moto.core.parsers import PROTOCOL_PARSERS
 from moto.core.request import determine_request_protocol, normalize_request
-from moto.core.serialize import SERIALIZERS, ResponseSerializer, XFormedAttributePicker
+from moto.core.serialize import (
+    ResponseSerializer,
+    XFormedAttributePicker,
+    get_serializer_class,
+)
 from moto.core.utils import (
     camelcase_to_underscores,
     get_service_model,
@@ -50,7 +50,7 @@ from moto.utilities.utils import get_partition
 
 log = logging.getLogger(__name__)
 
-JINJA_ENVS: Dict[type, Environment] = {}
+JINJA_ENVS: dict[type, Environment] = {}
 
 if TYPE_CHECKING:
     from typing_extensions import ParamSpec
@@ -65,8 +65,8 @@ ResponseShape = TypeVar("ResponseShape", bound="BaseResponse")
 boto3_service_name = {"awslambda": "lambda"}
 
 
-def _decode_dict(d: Dict[Any, Any]) -> Dict[str, Any]:
-    decoded: Dict[str, Any] = OrderedDict()
+def _decode_dict(d: dict[Any, Any]) -> dict[str, Any]:
+    decoded: dict[str, Any] = OrderedDict()
     for key, value in d.items():
         if isinstance(key, bytes):
             newkey = key.decode("utf-8")
@@ -89,9 +89,9 @@ def _decode_dict(d: Dict[Any, Any]) -> Dict[str, Any]:
     return decoded
 
 
-@functools.lru_cache(maxsize=None)
-def _get_method_urls(service_name: str, region: str) -> Dict[str, Dict[str, str]]:
-    method_urls: Dict[str, Dict[str, str]] = defaultdict(dict)
+@functools.cache
+def _get_method_urls(service_name: str, region: str) -> dict[str, dict[str, str]]:
+    method_urls: dict[str, dict[str, str]] = defaultdict(dict)
     service_name = boto3_service_name.get(service_name) or service_name  # type: ignore
     conn = boto3.client(service_name, region_name=region)
     op_names = conn._service_model.operation_names
@@ -124,14 +124,14 @@ def _get_method_urls(service_name: str, region: str) -> Dict[str, Dict[str, str]
 
 
 class DynamicDictLoader(DictLoader):
-    def update(self, mapping: Dict[str, str]) -> None:
+    def update(self, mapping: dict[str, str]) -> None:
         self.mapping.update(mapping)  # type: ignore[attr-defined]
 
     def contains(self, template: str) -> bool:
         return bool(template in self.mapping)
 
 
-class _TemplateEnvironmentMixin(object):
+class _TemplateEnvironmentMixin:
     LEFT_PATTERN = re.compile(r"[\s\n]+<")
     RIGHT_PATTERN = re.compile(r">[\s\n]+")
 
@@ -184,7 +184,7 @@ class _TemplateEnvironmentMixin(object):
         return self.environment.get_template(template_id)
 
 
-class ActionAuthenticatorMixin(object):
+class ActionAuthenticatorMixin:
     request_count: ClassVar[int] = 0
 
     PUBLIC_OPERATIONS = [
@@ -245,11 +245,11 @@ class ActionAuthenticatorMixin(object):
     @staticmethod
     def set_initial_no_auth_action_count(
         initial_no_auth_action_count: int,
-    ) -> "Callable[[Callable[P, T]], Callable[P, T]]":
+    ) -> Callable[[Callable[P, T]], Callable[P, T]]:
         _test_server_mode_endpoint = settings.test_server_mode_endpoint()
 
-        def decorator(function: "Callable[P, T]") -> "Callable[P, T]":
-            def wrapper(*args: "P.args", **kwargs: "P.kwargs") -> T:
+        def decorator(function: Callable[P, T]) -> Callable[P, T]:
+            def wrapper(*args: P.args, **kwargs: P.kwargs) -> T:
                 if settings.TEST_SERVER_MODE:
                     response = requests.post(
                         f"{_test_server_mode_endpoint}/moto-api/reset-auth",
@@ -337,6 +337,8 @@ class EmptyResult(ActionResult):
 
 
 class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
+    PROTOCOL_PARSER_MAP_TYPE: Any = dict
+
     default_region = "us-east-1"
     # to extract region, use [^.]
     # Note that the URL region can be anything, thanks to our MOTO_ALLOW_NONEXISTENT_REGION-config - so we can't have a very specific regex
@@ -395,7 +397,7 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
         """
         self.is_werkzeug_request = "werkzeug" in str(type(request))
         self.parsed_url = urlparse(full_url)
-        querystring: Dict[str, Any] = OrderedDict()
+        querystring: dict[str, Any] = OrderedDict()
         if hasattr(request, "body"):
             # Boto
             self.body = request.body
@@ -638,7 +640,7 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
             service_model, normalized_request.content_type
         )
         parser_cls = PROTOCOL_PARSERS[protocol]
-        parser = parser_cls(map_type=XFormedDict)  # type: ignore[no-untyped-call]
+        parser = parser_cls(map_type=self.PROTOCOL_PARSER_MAP_TYPE)  # type: ignore[no-untyped-call]
         parsed = parser.parse(
             {
                 "query_params": normalized_request.values,
@@ -660,7 +662,7 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
         service_model = get_service_model(self.service_name)
         operation_model = service_model.operation_model(self._get_action())
         protocol = self.determine_response_protocol(service_model)
-        serializer_cls = SERIALIZERS[protocol]
+        serializer_cls = get_serializer_class(service_model.service_name, protocol)
         context = ActionContext(
             service_model, operation_model, serializer_cls, self.__class__
         )
@@ -678,7 +680,7 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
         try:
             self._authenticate_and_authorize_normal_action(resource)
         except HTTPException as http_error:
-            response = http_error.description, dict(status=http_error.code)
+            response = http_error.description, {"status": http_error.code}
             status, headers, body = self._transform_response(headers, response)
             headers, body = self._enrich_response(headers, body)
 
@@ -696,7 +698,7 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
                 se_headers["status"] = se_status
                 response = se_body, se_headers  # type: ignore[assignment]
             except HTTPException as http_error:
-                response_headers: Dict[str, Union[str, int]] = dict(
+                response_headers: dict[str, Union[str, int]] = dict(
                     http_error.get_headers() or []
                 )
                 response_headers["status"] = http_error.code  # type: ignore[assignment]
@@ -720,7 +722,7 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
         raise NotImplementedError(f"The {action} action has not been implemented")
 
     @staticmethod
-    def _transform_response(headers: Dict[str, str], response: Any) -> TYPE_RESPONSE:  # type: ignore[misc]
+    def _transform_response(headers: dict[str, str], response: Any) -> TYPE_RESPONSE:  # type: ignore[misc]
         if response is None:
             response = "", {}
         if len(response) == 2:
@@ -733,8 +735,8 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
 
     @staticmethod
     def _enrich_response(  # type: ignore[misc]
-        headers: Dict[str, str], body: Any
-    ) -> Tuple[Dict[str, str], Any]:
+        headers: dict[str, str], body: Any
+    ) -> tuple[dict[str, str], Any]:
         # Cast status to string
         if "status" in headers:
             headers["status"] = str(headers["status"])
@@ -748,21 +750,9 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
             pass
         return headers, body
 
-    def _get_param(
-        self, param_name: str, if_none: Any = None, use_original_dict: bool = False
-    ) -> Any:
-        """
-        Get parameter from body/query/headers
-
-        :param use_original_dict Whether to return the data that was originally provided, or return the normalized (snake-case) dict
-        """
+    def _get_param(self, param_name: str, if_none: Any = None) -> Any:
         if self.automated_parameter_parsing:
-            params_to_use = (
-                self.params.original_dict()
-                if use_original_dict and isinstance(self.params, XFormedDict)
-                else self.params
-            )
-            return get_value(params_to_use, param_name, default=if_none)
+            return get_value(self.params, param_name, default=if_none)
 
         val = self.querystring.get(param_name)
         if val is not None:
@@ -817,16 +807,16 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
                 return False
         return if_none
 
-    def _get_multi_param_dict(self, param_prefix: str) -> Dict[str, Any]:
+    def _get_multi_param_dict(self, param_prefix: str) -> dict[str, Any]:
         return self._get_multi_param_helper(param_prefix, skip_result_conversion=True)
 
     def _get_multi_param_helper(
         self,
         param_prefix: str,
         skip_result_conversion: bool = False,
-        tracked_prefixes: Optional[Set[str]] = None,
+        tracked_prefixes: Optional[set[str]] = None,
     ) -> Any:
-        value_dict: Any = dict()
+        value_dict: Any = {}
         tracked_prefixes = (
             tracked_prefixes or set()
         )  # prefixes which have already been processed
@@ -891,7 +881,7 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
 
     def _get_multi_param(
         self, param_prefix: str, skip_result_conversion: bool = False
-    ) -> List[Any]:
+    ) -> list[Any]:
         """
         Given a querystring of ?LaunchConfigurationNames.member.1=my-test-1&LaunchConfigurationNames.member.2=my-test-2
         this will return ['my-test-1', 'my-test-2']
@@ -914,29 +904,7 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
 
         return values
 
-    def _get_dict_param(self, param_prefix: str) -> Dict[str, Any]:
-        """
-        Given a parameter dict of
-        {
-            'Instances.SlaveInstanceType': ['m1.small'],
-            'Instances.InstanceCount': ['1']
-        }
-
-        returns
-        {
-            "slave_instance_type": "m1.small",
-            "instance_count": "1",
-        }
-        """
-        params: Dict[str, Any] = {}
-        for key, value in self.querystring.items():
-            if key.startswith(param_prefix):
-                params[camelcase_to_underscores(key.replace(param_prefix, ""))] = value[
-                    0
-                ]
-        return params
-
-    def _get_params(self) -> Dict[str, Any]:
+    def _get_params(self) -> dict[str, Any]:
         """
         Given a querystring of
         {
@@ -974,7 +942,7 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
         """
         if self.automated_parameter_parsing:
             return self.params
-        params: Dict[str, Any] = {}
+        params: dict[str, Any] = {}
         for k, v in sorted(self.querystring.items(), key=params_sort_function):
             self._parse_param(k, v[0], params)
         return params
@@ -1013,7 +981,7 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
         else:
             obj[keylist[-1]] = value
 
-    def _get_list_prefix(self, param_prefix: str) -> List[Dict[str, Any]]:
+    def _get_list_prefix(self, param_prefix: str) -> list[dict[str, Any]]:
         """
         Given a query dict like
         {
@@ -1052,30 +1020,6 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
             param_index += 1
         return results
 
-    def _get_map_prefix(
-        self, param_prefix: str, key_end: str = ".key", value_end: str = ".value"
-    ) -> Dict[str, Any]:
-        results = {}
-        param_index = 1
-        while 1:
-            index_prefix = f"{param_prefix}.{param_index}."
-
-            k, v = None, None
-            for key, value in self.querystring.items():
-                if key.startswith(index_prefix):
-                    if key.endswith(key_end):
-                        k = value[0]
-                    elif key.endswith(value_end):
-                        v = value[0]
-
-            if not (k and v is not None):
-                break
-
-            results[k] = v
-            param_index += 1
-
-        return results
-
     @property
     def request_json(self) -> bool:
         return "JSON" in self.querystring.get("ContentType", [])
