@@ -1,4 +1,5 @@
-from typing import Any, Iterable, List, Optional, Union
+from collections.abc import Iterable
+from typing import Any, Optional, Union
 
 from moto.core.exceptions import RESTError
 
@@ -196,7 +197,7 @@ class InvalidCustomerGatewayIdError(EC2ClientError):
     def __init__(self, customer_gateway_id: str):
         super().__init__(
             "InvalidCustomerGatewayID.NotFound",
-            f"The customer gateway ID '{customer_gateway_id}' does not exist",
+            f"The customerGateway ID '{customer_gateway_id}' does not exist",
         )
 
 
@@ -254,6 +255,14 @@ class InvalidPermissionDuplicateError(EC2ClientError):
         )
 
 
+class DuplicateTransitGatewayAttachmentError(EC2ClientError):
+    def __init__(self, transit_gateway_id: str):
+        super().__init__(
+            "DuplicateTransitGatewayAttachment",
+            f"{transit_gateway_id} has non-deleted Transit Gateway Attachments with same VPC ID.",
+        )
+
+
 class InvalidRouteTableIdError(EC2ClientError):
     def __init__(self, route_table_id: str):
         super().__init__(
@@ -312,7 +321,7 @@ class InvalidInstanceTypeError(EC2ClientError):
 
 
 class InvalidAMIIdError(EC2ClientError):
-    def __init__(self, ami_id: Union[List[str], str]):
+    def __init__(self, ami_id: Union[list[str], str]):
         super().__init__(
             "InvalidAMIID.NotFound",
             f"The image id '[{ami_id}]' does not exist",
@@ -336,7 +345,7 @@ class InvalidAMIAttributeItemValueError(EC2ClientError):
 
 
 class MalformedAMIIdError(EC2ClientError):
-    def __init__(self, ami_id: List[str]):
+    def __init__(self, ami_id: list[str]):
         super().__init__(
             "InvalidAMIID.Malformed", f'Invalid id: "{ami_id}" (expecting "ami-...")'
         )
@@ -611,7 +620,7 @@ class CidrLimitExceeded(EC2ClientError):
     def __init__(self, vpc_id: str, max_cidr_limit: int):
         super().__init__(
             "CidrLimitExceeded",
-            f"This network '{vpc_id}' has met its maximum number of allowed CIDRs: {max_cidr_limit}",
+            f"This network {vpc_id} has met its maximum number of allowed CIDRs: {max_cidr_limit}",
         )
 
 
@@ -860,6 +869,14 @@ class InvalidCarrierGatewayID(EC2ClientError):
         )
 
 
+class InvalidTransitGatewayID(EC2ClientError):
+    def __init__(self, transit_gateway_id: str, msg: Optional[str] = None):
+        super().__init__(
+            "InvalidTransitGatewayID.NotFound",
+            msg or f"The transitGateway ID '{transit_gateway_id}' does not exist",
+        )
+
+
 class NoLoadBalancersProvided(EC2ClientError):
     def __init__(self) -> None:
         super().__init__(
