@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Any, Optional, Union
 
 from moto.core.common_models import CloudFormationModel
 
@@ -42,13 +42,13 @@ class NetworkInterface(TaggedEC2Resource, CloudFormationModel):
         self,
         ec2_backend: Any,
         subnet: Any,
-        private_ip_address: Union[List[str], str],
-        private_ip_addresses: Optional[List[Dict[str, Any]]] = None,
+        private_ip_address: Union[list[str], str],
+        private_ip_addresses: Optional[list[dict[str, Any]]] = None,
         device_index: int = 0,
         public_ip_auto_assign: bool = False,
-        group_ids: Optional[List[str]] = None,
+        group_ids: Optional[list[str]] = None,
         description: Optional[str] = None,
-        tags: Optional[Dict[str, str]] = None,
+        tags: Optional[dict[str, str]] = None,
         delete_on_termination: Optional[bool] = False,
         **kwargs: Any,
     ):
@@ -58,7 +58,7 @@ class NetworkInterface(TaggedEC2Resource, CloudFormationModel):
         if isinstance(private_ip_address, list) and private_ip_address:
             private_ip_address = private_ip_address[0]
         self.private_ip_address: Optional[str] = private_ip_address or None  # type: ignore
-        self.private_ip_addresses: List[Dict[str, Any]] = private_ip_addresses or []
+        self.private_ip_addresses: list[dict[str, Any]] = private_ip_addresses or []
         self.ipv6_addresses = kwargs.get("ipv6_addresses") or []
 
         self.subnet = subnet
@@ -75,6 +75,8 @@ class NetworkInterface(TaggedEC2Resource, CloudFormationModel):
         self.public_ip_auto_assign = public_ip_auto_assign
         self.start()
         self.add_tags(tags or {})
+        self.requester_managed = False
+        self.requester_id = "AIDAIT2UOQQY3AUEMOTO"
         self.status = "available"
         self.mac_address = random_mac_address()
         self.interface_type = "interface"
@@ -174,8 +176,8 @@ class NetworkInterface(TaggedEC2Resource, CloudFormationModel):
         return addresses
 
     @property
-    def association(self) -> Dict[str, Any]:  # type: ignore[misc]
-        association: Dict[str, Any] = {}
+    def association(self) -> dict[str, Any]:  # type: ignore[misc]
+        association: dict[str, Any] = {}
         if self.public_ip:
             eips = self.ec2_backend.address_by_ip(
                 [self.public_ip], fail_if_not_found=False
@@ -185,6 +187,9 @@ class NetworkInterface(TaggedEC2Resource, CloudFormationModel):
                 association["allocationId"] = eip.allocation_id or None
                 association["associationId"] = eip.association_id or None
             association["natEnabled"] = True
+            association["publicIp"] = self.public_ip
+            association["publicDnsName"] = generate_dns_from_ip(self.public_ip)
+            association["ipOwnerId"] = self.ec2_backend.account_id
         return association
 
     @property
@@ -216,7 +221,7 @@ class NetworkInterface(TaggedEC2Resource, CloudFormationModel):
         account_id: str,
         region_name: str,
         **kwargs: Any,
-    ) -> "NetworkInterface":
+    ) -> NetworkInterface:
         from ..models import ec2_backends
 
         properties = cloudformation_json["Properties"]
@@ -313,16 +318,16 @@ class NetworkInterface(TaggedEC2Resource, CloudFormationModel):
 
 class NetworkInterfaceBackend:
     def __init__(self) -> None:
-        self.enis: Dict[str, NetworkInterface] = {}
+        self.enis: dict[str, NetworkInterface] = {}
 
     def create_network_interface(
         self,
         subnet: Any,
-        private_ip_address: Union[str, List[str]],
-        private_ip_addresses: Optional[List[Dict[str, Any]]] = None,
-        group_ids: Optional[List[str]] = None,
+        private_ip_address: Union[str, list[str]],
+        private_ip_addresses: Optional[list[dict[str, Any]]] = None,
+        group_ids: Optional[list[str]] = None,
         description: Optional[str] = None,
-        tags: Optional[Dict[str, str]] = None,
+        tags: Optional[dict[str, str]] = None,
         delete_on_termination: Optional[bool] = False,
         **kwargs: Any,
     ) -> NetworkInterface:
@@ -353,7 +358,7 @@ class NetworkInterfaceBackend:
 
     def describe_network_interfaces(
         self, filters: Any = None
-    ) -> List[NetworkInterface]:
+    ) -> list[NetworkInterface]:
         # Note: This is only used in EC2Backend#do_resources_exist
         # Client-calls use #get_all_network_interfaces()
         # We should probably merge these at some point..
@@ -393,7 +398,7 @@ class NetworkInterfaceBackend:
     def modify_network_interface_attribute(
         self,
         eni_id: str,
-        group_ids: List[str],
+        group_ids: list[str],
         source_dest_check: Optional[bool] = None,
         description: Optional[str] = None,
     ) -> None:
@@ -408,22 +413,20 @@ class NetworkInterfaceBackend:
             eni.description = description
 
     def get_all_network_interfaces(
-        self, eni_ids: Optional[List[str]] = None, filters: Any = None
-    ) -> List[NetworkInterface]:
+        self, eni_ids: Optional[list[str]] = None, filters: Any = None
+    ) -> list[NetworkInterface]:
         enis = list(self.enis.values())
 
         if eni_ids:
             enis = [eni for eni in enis if eni.id in eni_ids]
             if len(enis) != len(eni_ids):
-                invalid_id = list(
-                    set(eni_ids).difference(set([eni.id for eni in enis]))
-                )[0]
+                invalid_id = list(set(eni_ids).difference({eni.id for eni in enis}))[0]
                 raise InvalidNetworkInterfaceIdError(invalid_id)
 
         return generic_filter(filters, enis)
 
     def unassign_private_ip_addresses(
-        self, eni_id: str, private_ip_address: Optional[List[str]] = None
+        self, eni_id: str, private_ip_address: Optional[list[str]] = None
     ) -> NetworkInterface:
         eni = self.get_network_interface(eni_id)
         if private_ip_address:
@@ -435,7 +438,7 @@ class NetworkInterfaceBackend:
     def assign_private_ip_addresses(
         self,
         eni_id: str,
-        private_ip_addresses: Optional[List[str]] = None,
+        private_ip_addresses: Optional[list[str]] = None,
         secondary_ips_count: Optional[int] = None,
     ) -> NetworkInterface:
         eni = self.get_network_interface(eni_id)
@@ -461,13 +464,13 @@ class NetworkInterfaceBackend:
     def assign_ipv6_addresses(
         self,
         eni_id: str,
-        ipv6_addresses: Optional[List[str]] = None,
+        ipv6_addresses: Optional[list[str]] = None,
         ipv6_count: Optional[int] = None,
     ) -> NetworkInterface:
         eni = self.get_network_interface(eni_id)
         if ipv6_addresses:
             eni.ipv6_addresses.extend(
-                (ip for ip in ipv6_addresses if ip not in eni.ipv6_addresses)
+                ip for ip in ipv6_addresses if ip not in eni.ipv6_addresses
             )
 
         while ipv6_count:
@@ -480,7 +483,7 @@ class NetworkInterfaceBackend:
         return eni
 
     def unassign_ipv6_addresses(
-        self, eni_id: str, ips: Optional[List[str]] = None
+        self, eni_id: str, ips: Optional[list[str]] = None
     ) -> list[str]:
         unassigned_addresses = []
         eni = self.get_network_interface(eni_id)
