@@ -1,21 +1,21 @@
-from __future__ import unicode_literals
-from jinja2 import Template
-
-from moto.core.responses import BaseResponse
-from moto.ec2.utils import instance_ids_from_querystring
+from ._base_response import EC2BaseResponse
 
 
-class General(BaseResponse):
-    def get_console_output(self):
-        self.instance_ids = instance_ids_from_querystring(self.querystring)
-        instance_id = self.instance_ids[0]
+class General(EC2BaseResponse):
+    def get_console_output(self) -> str:
+        instance_id = self._get_param("InstanceId")
+        if not instance_id:
+            # For compatibility with boto.
+            # See: https://github.com/getmoto/moto/pull/1152#issuecomment-332487599
+            instance_id = self._get_multi_param("InstanceId")[0]
+
         instance = self.ec2_backend.get_instance(instance_id)
-        template = Template(GET_CONSOLE_OUTPUT_RESULT)
+        template = self.response_template(GET_CONSOLE_OUTPUT_RESULT)
         return template.render(instance=instance)
 
 
-GET_CONSOLE_OUTPUT_RESULT = '''
-<GetConsoleOutputResponse xmlns="http://ec2.amazonaws.com/doc/2012-12-01/">
+GET_CONSOLE_OUTPUT_RESULT = """
+<GetConsoleOutputResponse xmlns="http://ec2.amazonaws.com/doc/2013-10-15/">
   <requestId>59dbff89-35bd-4eac-99ed-be587EXAMPLE</requestId>
   <instanceId>{{ instance.id }}</instanceId>
   <timestamp>2010-10-14T01:12:41.000Z</timestamp>
@@ -27,4 +27,4 @@ R0hNRU0gYXZhaWxhYmxlLgo3MjdNQiBMT1dNRU0gYXZhaWxhYmxlLgpOWCAoRXhlY3V0ZSBEaXNh
 YmxlKSBwcm90ZWN0aW9uOiBhY3RpdmUKSVJRIGxvY2t1cCBkZXRlY3Rpb24gZGlzYWJsZWQKQnVp
 bHQgMSB6b25lbGlzdHMKS2VybmVsIGNvbW1hbmQgbGluZTogcm9vdD0vZGV2L3NkYTEgcm8gNApF
 bmFibGluZyBmYXN0IEZQVSBzYXZlIGFuZCByZXN0b3JlLi4uIGRvbmUuCg==</output>
-</GetConsoleOutputResponse>'''
+</GetConsoleOutputResponse>"""
