@@ -1,5 +1,5 @@
 from copy import deepcopy
-from typing import Any, Dict, List, Optional
+from typing import Any, Optional
 
 from moto.core.utils import camelcase_to_underscores
 from moto.ec2.exceptions import (
@@ -183,8 +183,8 @@ class InstanceResponse(EC2BaseResponse):
         return template.render(instances=instances)
 
     def _get_list_of_dict_params(
-        self, param_prefix: str, _dct: Dict[str, Any]
-    ) -> List[Any]:
+        self, param_prefix: str, _dct: dict[str, Any]
+    ) -> list[Any]:
         """
         Simplified version of _get_dict_param
         Allows you to pass in a custom dict instead of using self.querystring by default
@@ -344,7 +344,7 @@ class InstanceResponse(EC2BaseResponse):
 
     def _dot_value_instance_attribute_handler(self) -> Optional[str]:
         attribute_key = None
-        for key, value in self.querystring.items():
+        for key in self.querystring:
             if ".Value" in key:
                 attribute_key = key
                 break
@@ -392,12 +392,12 @@ class InstanceResponse(EC2BaseResponse):
         )
         return EC2_MODIFY_INSTANCE_ATTRIBUTE
 
-    def _parse_block_device_mapping(self) -> List[Dict[str, Any]]:
+    def _parse_block_device_mapping(self) -> list[dict[str, Any]]:
         device_mappings = self._get_list_prefix("BlockDeviceMapping")
         mappings = []
         for device_mapping in device_mappings:
             self._validate_block_device_mapping(device_mapping)
-            device_template: Dict[str, Any] = deepcopy(BLOCK_DEVICE_MAPPING_TEMPLATE)
+            device_template: dict[str, Any] = deepcopy(BLOCK_DEVICE_MAPPING_TEMPLATE)
             device_template["VirtualName"] = device_mapping.get("virtual_name")
             device_template["DeviceName"] = device_mapping.get("device_name")
             device_template["Ebs"]["SnapshotId"] = device_mapping.get(
@@ -423,7 +423,7 @@ class InstanceResponse(EC2BaseResponse):
         return mappings
 
     @staticmethod
-    def _validate_block_device_mapping(device_mapping: Dict[str, Any]) -> None:  # type: ignore[misc]
+    def _validate_block_device_mapping(device_mapping: dict[str, Any]) -> None:  # type: ignore[misc]
         from botocore import __version__ as botocore_version
 
         if "no_device" in device_mapping:
