@@ -1,48 +1,100 @@
 import json
+from typing import Any
 
 from moto.core.responses import BaseResponse
-from .models import ecs_backends
+from moto.core.utils import camelcase_to_underscores
+
+from .models import EC2ContainerServiceBackend, ecs_backends
 
 
 class EC2ContainerServiceResponse(BaseResponse):
-    @property
-    def ecs_backend(self):
-        """
-        ECS Backend
-
-        :return: ECS Backend object
-        :rtype: moto.ecs.models.EC2ContainerServiceBackend
-        """
-        return ecs_backends[self.region]
+    def __init__(self) -> None:
+        super().__init__(service_name="ecs")
 
     @property
-    def request_params(self):
-        try:
-            return json.loads(self.body)
-        except ValueError:
-            return {}
+    def ecs_backend(self) -> EC2ContainerServiceBackend:
+        return ecs_backends[self.current_account][self.region]
 
-    def _get_param(self, param, if_none=None):
-        return self.request_params.get(param, if_none)
+    def create_capacity_provider(self) -> str:
+        name = self._get_param("name")
+        asg_provider = self._get_param("autoScalingGroupProvider")
+        tags = self._get_param("tags")
+        provider = self.ecs_backend.create_capacity_provider(name, asg_provider, tags)
+        return json.dumps({"capacityProvider": provider.response_object})
 
-    def create_cluster(self):
+    def create_cluster(self) -> str:
         cluster_name = self._get_param("clusterName")
         tags = self._get_param("tags")
+        settings = self._get_param("settings")
+        configuration = self._get_param("configuration")
+        capacity_providers = self._get_param("capacityProviders")
+        default_capacity_provider_strategy = self._get_param(
+            "defaultCapacityProviderStrategy"
+        )
+        service_connect_defaults = self._get_param("serviceConnectDefaults")
         if cluster_name is None:
             cluster_name = "default"
-        cluster = self.ecs_backend.create_cluster(cluster_name, tags)
+        cluster = self.ecs_backend.create_cluster(
+            cluster_name,
+            tags,
+            settings,
+            configuration,
+            capacity_providers,
+            default_capacity_provider_strategy,
+            service_connect_defaults=service_connect_defaults,
+        )
         return json.dumps({"cluster": cluster.response_object})
 
-    def list_clusters(self):
+    def list_clusters(self) -> str:
         cluster_arns = self.ecs_backend.list_clusters()
+        return json.dumps({"clusterArns": cluster_arns})
+
+    def update_cluster(self) -> str:
+        cluster_name = self._get_param("cluster")
+        settings = self._get_param("settings")
+        configuration = self._get_param("configuration")
+        service_connect_defaults = self._get_param("serviceConnectDefaults")
+        cluster = self.ecs_backend.update_cluster(
+            cluster_name=cluster_name,
+            cluster_settings=settings,
+            configuration=configuration,
+            service_connect_defaults=service_connect_defaults,
+        )
+        return json.dumps({"cluster": cluster.response_object})
+
+    def put_cluster_capacity_providers(self) -> str:
+        cluster_name = self._get_param("cluster")
+        capacity_providers = self._get_param("capacityProviders")
+        default_capacity_provider_strategy = self._get_param(
+            "defaultCapacityProviderStrategy"
+        )
+        cluster = self.ecs_backend.put_cluster_capacity_providers(
+            cluster_name, capacity_providers, default_capacity_provider_strategy
+        )
+        return json.dumps({"cluster": cluster.response_object})
+
+    def delete_capacity_provider(self) -> str:
+        name = self._get_param("capacityProvider")
+        provider = self.ecs_backend.delete_capacity_provider(name)
+        return json.dumps({"capacityProvider": provider.response_object})
+
+    def update_capacity_provider(self) -> str:
+        name = self._get_param("name")
+        asg_provider = self._get_param("autoScalingGroupProvider")
+        provider = self.ecs_backend.update_capacity_provider(name, asg_provider)
+        return json.dumps({"capacityProvider": provider.response_object})
+
+    def describe_capacity_providers(self) -> str:
+        names = self._get_param("capacityProviders")
+        providers, failures = self.ecs_backend.describe_capacity_providers(names)
         return json.dumps(
             {
-                "clusterArns": cluster_arns
-                #  'nextToken': str(uuid.uuid4())
+                "capacityProviders": [p.response_object for p in providers],
+                "failures": [p.response_object for p in failures],
             }
         )
 
-    def describe_clusters(self):
+    def describe_clusters(self) -> str:
         names = self._get_param("clusters")
         include = self._get_param("include")
         clusters, failures = self.ecs_backend.describe_clusters(names, include)
@@ -53,12 +105,12 @@ class EC2ContainerServiceResponse(BaseResponse):
             }
         )
 
-    def delete_cluster(self):
+    def delete_cluster(self) -> str:
         cluster_str = self._get_param("cluster")
         cluster = self.ecs_backend.delete_cluster(cluster_str)
         return json.dumps({"cluster": cluster.response_object})
 
-    def register_task_definition(self):
+    def register_task_definition(self) -> str:
         family = self._get_param("family")
         container_definitions = self._get_param("containerDefinitions")
         volumes = self._get_param("volumes")
@@ -70,6 +122,12 @@ class EC2ContainerServiceResponse(BaseResponse):
         memory = self._get_param("memory")
         task_role_arn = self._get_param("taskRoleArn")
         execution_role_arn = self._get_param("executionRoleArn")
+        proxy_configuration = self._get_param("proxyConfiguration")
+        inference_accelerators = self._get_param("inferenceAccelerators")
+        runtime_platform = self._get_param("runtimePlatform")
+        ipc_mode = self._get_param("ipcMode")
+        pid_mode = self._get_param("pidMode")
+        ephemeral_storage = self._get_param("ephemeralStorage")
 
         task_definition = self.ecs_backend.register_task_definition(
             family,
@@ -83,77 +141,107 @@ class EC2ContainerServiceResponse(BaseResponse):
             memory=memory,
             task_role_arn=task_role_arn,
             execution_role_arn=execution_role_arn,
+            proxy_configuration=proxy_configuration,
+            inference_accelerators=inference_accelerators,
+            runtime_platform=runtime_platform,
+            ipc_mode=ipc_mode,
+            pid_mode=pid_mode,
+            ephemeral_storage=ephemeral_storage,
         )
-        return json.dumps({"taskDefinition": task_definition.response_object})
+        return json.dumps(task_definition.response_object)
 
-    def list_task_definitions(self):
+    def list_task_definitions(self) -> str:
         family_prefix = self._get_param("familyPrefix")
-        task_definition_arns = self.ecs_backend.list_task_definitions(family_prefix)
-        return json.dumps(
-            {
-                "taskDefinitionArns": task_definition_arns
-                #  'nextToken': str(uuid.uuid4())
-            }
+        status = self._get_param("status", "ACTIVE")
+        task_definition_arns = self.ecs_backend.list_task_definitions(
+            family_prefix, status
         )
+        return json.dumps({"taskDefinitionArns": task_definition_arns})
 
-    def describe_task_definition(self):
+    def describe_task_definition(self) -> str:
         task_definition_str = self._get_param("taskDefinition")
         data = self.ecs_backend.describe_task_definition(task_definition_str)
-        resp = {"taskDefinition": data.response_object, "failures": []}
+        resp: dict[str, Any] = data.response_object
+        resp["failures"] = []
         if "TAGS" in self._get_param("include", []):
             resp["tags"] = self.ecs_backend.list_tags_for_resource(data.arn)
         return json.dumps(resp)
 
-    def deregister_task_definition(self):
+    def deregister_task_definition(self) -> str:
         task_definition_str = self._get_param("taskDefinition")
         task_definition = self.ecs_backend.deregister_task_definition(
             task_definition_str
         )
-        return json.dumps({"taskDefinition": task_definition.response_object})
+        return json.dumps(task_definition.response_object)
 
-    def run_task(self):
+    def run_task(self) -> str:
         cluster_str = self._get_param("cluster", "default")
         overrides = self._get_param("overrides")
         task_definition_str = self._get_param("taskDefinition")
-        count = self._get_int_param("count")
+        count = self._get_int_param("count", 1)
         started_by = self._get_param("startedBy")
         tags = self._get_param("tags")
+        launch_type = self._get_param("launchType")
+        network_configuration = self._get_param("networkConfiguration")
+        group = self._get_param("group")
+        platform_version = self._get_param("platformVersion")
         tasks = self.ecs_backend.run_task(
-            cluster_str, task_definition_str, count, overrides, started_by, tags
+            cluster_str,
+            task_definition_str,
+            count,
+            overrides,
+            started_by,
+            tags,
+            launch_type,
+            network_configuration,
+            group,
+            platform_version,
         )
         return json.dumps(
-            {"tasks": [task.response_object for task in tasks], "failures": []}
+            {"tasks": [task.response_object() for task in tasks], "failures": []}
         )
 
-    def describe_tasks(self):
+    def describe_tasks(self) -> str:
         cluster = self._get_param("cluster", "default")
         tasks = self._get_param("tasks")
+        include_tags = "TAGS" in self._get_param("include", [])
         data = self.ecs_backend.describe_tasks(cluster, tasks)
         return json.dumps(
-            {"tasks": [task.response_object for task in data], "failures": []}
+            {
+                "tasks": [task.response_object(include_tags) for task in data],
+                "failures": [],
+            }
         )
 
-    def start_task(self):
+    def start_task(self) -> str:
         cluster_str = self._get_param("cluster", "default")
         overrides = self._get_param("overrides")
         task_definition_str = self._get_param("taskDefinition")
         container_instances = self._get_param("containerInstances")
         started_by = self._get_param("startedBy")
+        tags = self._get_param("tags")
+        group = self._get_param("group")
         tasks = self.ecs_backend.start_task(
-            cluster_str, task_definition_str, container_instances, overrides, started_by
+            cluster_str,
+            task_definition_str,
+            container_instances,
+            overrides,
+            started_by,
+            tags,
+            group,
         )
         return json.dumps(
-            {"tasks": [task.response_object for task in tasks], "failures": []}
+            {"tasks": [task.response_object() for task in tasks], "failures": []}
         )
 
-    def list_tasks(self):
+    def list_tasks(self) -> str:
         cluster_str = self._get_param("cluster", "default")
         container_instance = self._get_param("containerInstance")
         family = self._get_param("family")
         started_by = self._get_param("startedBy")
         service_name = self._get_param("serviceName")
         desiredStatus = self._get_param("desiredStatus")
-        task_arns = self.ecs_backend.list_tasks(
+        tasks = self.ecs_backend.list_tasks(
             cluster_str,
             container_instance,
             family,
@@ -161,16 +249,16 @@ class EC2ContainerServiceResponse(BaseResponse):
             service_name,
             desiredStatus,
         )
-        return json.dumps({"taskArns": task_arns})
+        return json.dumps({"taskArns": [t.task_arn for t in tasks]})
 
-    def stop_task(self):
+    def stop_task(self) -> str:
         cluster_str = self._get_param("cluster", "default")
         task = self._get_param("task")
         reason = self._get_param("reason")
         task = self.ecs_backend.stop_task(cluster_str, task, reason)
-        return json.dumps({"task": task.response_object})
+        return json.dumps({"task": task.response_object()})
 
-    def create_service(self):
+    def create_service(self) -> str:
         cluster_str = self._get_param("cluster", "default")
         service_name = self._get_param("serviceName")
         task_definition_str = self._get_param("taskDefinition")
@@ -181,6 +269,10 @@ class EC2ContainerServiceResponse(BaseResponse):
         tags = self._get_param("tags")
         deployment_controller = self._get_param("deploymentController")
         launch_type = self._get_param("launchType")
+        platform_version = self._get_param("platformVersion")
+        propagate_tags = self._get_param("propagateTags") or "NONE"
+        network_configuration = self._get_param("networkConfiguration")
+        role = self._get_param("role")
         service = self.ecs_backend.create_service(
             cluster_str,
             service_name,
@@ -191,23 +283,24 @@ class EC2ContainerServiceResponse(BaseResponse):
             tags,
             deployment_controller,
             launch_type,
+            network_configuration=network_configuration,
             service_registries=service_registries,
+            platform_version=platform_version,
+            propagate_tags=propagate_tags,
+            role_arn=role,
         )
         return json.dumps({"service": service.response_object})
 
-    def list_services(self):
+    def list_services(self) -> str:
         cluster_str = self._get_param("cluster", "default")
         scheduling_strategy = self._get_param("schedulingStrategy")
-        service_arns = self.ecs_backend.list_services(cluster_str, scheduling_strategy)
-        return json.dumps(
-            {
-                "serviceArns": service_arns
-                # ,
-                # 'nextToken': str(uuid.uuid4())
-            }
+        launch_type = self._get_param("launchType")
+        service_arns = self.ecs_backend.list_services(
+            cluster_str, scheduling_strategy, launch_type=launch_type
         )
+        return json.dumps({"serviceArns": service_arns})
 
-    def describe_services(self):
+    def describe_services(self) -> str:
         cluster_str = self._get_param("cluster", "default")
         service_names = self._get_param("services")
         services, failures = self.ecs_backend.describe_services(
@@ -224,24 +317,23 @@ class EC2ContainerServiceResponse(BaseResponse):
                 )
         return json.dumps(resp)
 
-    def update_service(self):
-        cluster_str = self._get_param("cluster", "default")
-        service_name = self._get_param("service")
-        task_definition = self._get_param("taskDefinition")
-        desired_count = self._get_int_param("desiredCount")
-        service = self.ecs_backend.update_service(
-            cluster_str, service_name, task_definition, desired_count
-        )
+    def update_service(self) -> str:
+        service_properties = json.loads(self.body)
+        parsed_props = {}
+        for k, v in service_properties.items():
+            parsed_props[camelcase_to_underscores(k)] = v
+
+        service = self.ecs_backend.update_service(parsed_props)
         return json.dumps({"service": service.response_object})
 
-    def delete_service(self):
+    def delete_service(self) -> str:
         service_name = self._get_param("service")
         cluster_name = self._get_param("cluster", "default")
         force = self._get_param("force", False)
         service = self.ecs_backend.delete_service(cluster_name, service_name, force)
         return json.dumps({"service": service.response_object})
 
-    def register_container_instance(self):
+    def register_container_instance(self) -> str:
         cluster_str = self._get_param("cluster", "default")
         instance_identity_document_str = self._get_param("instanceIdentityDocument")
         instance_identity_document = json.loads(instance_identity_document_str)
@@ -251,21 +343,21 @@ class EC2ContainerServiceResponse(BaseResponse):
         )
         return json.dumps({"containerInstance": container_instance.response_object})
 
-    def deregister_container_instance(self):
+    def deregister_container_instance(self) -> str:
         cluster_str = self._get_param("cluster", "default")
         container_instance_str = self._get_param("containerInstance")
         force = self._get_param("force")
-        container_instance, failures = self.ecs_backend.deregister_container_instance(
+        container_instance = self.ecs_backend.deregister_container_instance(
             cluster_str, container_instance_str, force
         )
         return json.dumps({"containerInstance": container_instance.response_object})
 
-    def list_container_instances(self):
+    def list_container_instances(self) -> str:
         cluster_str = self._get_param("cluster", "default")
         container_instance_arns = self.ecs_backend.list_container_instances(cluster_str)
         return json.dumps({"containerInstanceArns": container_instance_arns})
 
-    def describe_container_instances(self):
+    def describe_container_instances(self) -> str:
         cluster_str = self._get_param("cluster", "default")
         list_container_instance_arns = self._get_param("containerInstances")
         container_instances, failures = self.ecs_backend.describe_container_instances(
@@ -280,7 +372,7 @@ class EC2ContainerServiceResponse(BaseResponse):
             }
         )
 
-    def update_container_instances_state(self):
+    def update_container_instances_state(self) -> str:
         cluster_str = self._get_param("cluster", "default")
         list_container_instance_arns = self._get_param("containerInstances")
         status_str = self._get_param("status")
@@ -299,7 +391,7 @@ class EC2ContainerServiceResponse(BaseResponse):
             }
         )
 
-    def put_attributes(self):
+    def put_attributes(self) -> str:
         cluster_name = self._get_param("cluster")
         attributes = self._get_param("attributes")
 
@@ -307,16 +399,14 @@ class EC2ContainerServiceResponse(BaseResponse):
 
         return json.dumps({"attributes": attributes})
 
-    def list_attributes(self):
+    def list_attributes(self) -> str:
         cluster_name = self._get_param("cluster")
         attr_name = self._get_param("attributeName")
         attr_value = self._get_param("attributeValue")
         target_type = self._get_param("targetType")
-        max_results = self._get_param("maxResults")
-        next_token = self._get_param("nextToken")
 
         results = self.ecs_backend.list_attributes(
-            target_type, cluster_name, attr_name, attr_value, max_results, next_token
+            target_type, cluster_name, attr_name, attr_value
         )
         # Result will be [item will be {0 cluster_name, 1 arn, 2 name, 3 value}]
 
@@ -329,7 +419,7 @@ class EC2ContainerServiceResponse(BaseResponse):
 
         return json.dumps({"attributes": formatted_results})
 
-    def delete_attributes(self):
+    def delete_attributes(self) -> str:
         cluster_name = self._get_param("cluster", "default")
         attributes = self._get_param("attributes")
 
@@ -337,7 +427,7 @@ class EC2ContainerServiceResponse(BaseResponse):
 
         return json.dumps({"attributes": attributes})
 
-    def discover_poll_endpoint(self):
+    def discover_poll_endpoint(self) -> str:
         # Here are the arguments, this api is used by the ecs client so obviously no decent
         # documentation. Hence I've responded with valid but useless data
         # cluster_name = self._get_param('cluster')
@@ -346,36 +436,30 @@ class EC2ContainerServiceResponse(BaseResponse):
             {"endpoint": "http://localhost", "telemetryEndpoint": "http://localhost"}
         )
 
-    def list_task_definition_families(self):
+    def list_task_definition_families(self) -> str:
         family_prefix = self._get_param("familyPrefix")
-        status = self._get_param("status")
-        max_results = self._get_param("maxResults")
-        next_token = self._get_param("nextToken")
-
-        results = self.ecs_backend.list_task_definition_families(
-            family_prefix, status, max_results, next_token
-        )
+        results = self.ecs_backend.list_task_definition_families(family_prefix)
 
         return json.dumps({"families": list(results)})
 
-    def list_tags_for_resource(self):
+    def list_tags_for_resource(self) -> str:
         resource_arn = self._get_param("resourceArn")
         tags = self.ecs_backend.list_tags_for_resource(resource_arn)
         return json.dumps({"tags": tags})
 
-    def tag_resource(self):
+    def tag_resource(self) -> str:
         resource_arn = self._get_param("resourceArn")
         tags = self._get_param("tags")
-        results = self.ecs_backend.tag_resource(resource_arn, tags)
-        return json.dumps(results)
+        self.ecs_backend.tag_resource(resource_arn, tags)
+        return json.dumps({})
 
-    def untag_resource(self):
+    def untag_resource(self) -> str:
         resource_arn = self._get_param("resourceArn")
         tag_keys = self._get_param("tagKeys")
-        results = self.ecs_backend.untag_resource(resource_arn, tag_keys)
-        return json.dumps(results)
+        self.ecs_backend.untag_resource(resource_arn, tag_keys)
+        return json.dumps({})
 
-    def create_task_set(self):
+    def create_task_set(self) -> str:
         service_str = self._get_param("service")
         cluster_str = self._get_param("cluster", "default")
         task_definition = self._get_param("taskDefinition")
@@ -406,13 +490,13 @@ class EC2ContainerServiceResponse(BaseResponse):
         )
         return json.dumps({"taskSet": task_set.response_object})
 
-    def describe_task_sets(self):
+    def describe_task_sets(self) -> str:
         cluster_str = self._get_param("cluster", "default")
         service_str = self._get_param("service")
         task_sets = self._get_param("taskSets")
         include = self._get_param("include", [])
         task_set_objs = self.ecs_backend.describe_task_sets(
-            cluster_str, service_str, task_sets, include
+            cluster_str, service_str, task_sets
         )
 
         response_objs = [t.response_object for t in task_set_objs]
@@ -421,17 +505,14 @@ class EC2ContainerServiceResponse(BaseResponse):
                 del ro["tags"]
         return json.dumps({"taskSets": response_objs})
 
-    def delete_task_set(self):
+    def delete_task_set(self) -> str:
         cluster_str = self._get_param("cluster")
         service_str = self._get_param("service")
         task_set = self._get_param("taskSet")
-        force = self._get_param("force")
-        task_set = self.ecs_backend.delete_task_set(
-            cluster_str, service_str, task_set, force
-        )
+        task_set = self.ecs_backend.delete_task_set(cluster_str, service_str, task_set)
         return json.dumps({"taskSet": task_set.response_object})
 
-    def update_task_set(self):
+    def update_task_set(self) -> str:
         cluster_str = self._get_param("cluster", "default")
         service_str = self._get_param("service")
         task_set = self._get_param("taskSet")
@@ -442,7 +523,7 @@ class EC2ContainerServiceResponse(BaseResponse):
         )
         return json.dumps({"taskSet": task_set.response_object})
 
-    def update_service_primary_task_set(self):
+    def update_service_primary_task_set(self) -> str:
         cluster_str = self._get_param("cluster", "default")
         service_str = self._get_param("service")
         primary_task_set = self._get_param("primaryTaskSet")
@@ -452,19 +533,34 @@ class EC2ContainerServiceResponse(BaseResponse):
         )
         return json.dumps({"taskSet": task_set.response_object})
 
-    def put_account_setting(self):
+    def put_account_setting(self) -> str:
         name = self._get_param("name")
         value = self._get_param("value")
         account_setting = self.ecs_backend.put_account_setting(name, value)
         return json.dumps({"setting": account_setting.response_object})
 
-    def list_account_settings(self):
+    def list_account_settings(self) -> str:
         name = self._get_param("name")
         value = self._get_param("value")
         account_settings = self.ecs_backend.list_account_settings(name, value)
         return json.dumps({"settings": [s.response_object for s in account_settings]})
 
-    def delete_account_setting(self):
+    def delete_account_setting(self) -> str:
         name = self._get_param("name")
         self.ecs_backend.delete_account_setting(name)
         return "{}"
+
+    def delete_task_definitions(self) -> str:
+        task_definitions = self._get_param("taskDefinitions")
+        deleted_task_definitions, failures = self.ecs_backend.delete_task_definitions(
+            task_definitions=task_definitions,
+        )
+        return json.dumps(
+            {
+                "taskDefinitions": [
+                    td.response_object["taskDefinition"]
+                    for td in deleted_task_definitions
+                ],
+                "failures": [f.response_object for f in failures],
+            }
+        )
