@@ -3,9 +3,10 @@ import contextlib
 import json
 import re
 from collections import OrderedDict
+from collections.abc import Iterable
 from datetime import timedelta
 from functools import lru_cache
-from typing import Any, Dict, Iterable, List, Optional, Set, Tuple, cast
+from typing import Any, Optional, cast
 
 import cryptography
 import requests
@@ -86,14 +87,14 @@ class Topic(CloudFormationModel):
         self.subscriptions_pending = 0
         self.subscriptions_confimed = 0
         self.subscriptions_deleted = 0
-        self.sent_notifications: List[
-            Tuple[str, str, Optional[str], Optional[Dict[str, Any]], Optional[str]]
+        self.sent_notifications: list[
+            tuple[str, str, Optional[str], Optional[dict[str, Any]], Optional[str]]
         ] = []
 
         self._policy_json = self._create_default_topic_policy(
             sns_backend.region_name, self.account_id, name
         )
-        self._tags: Dict[str, str] = {}
+        self._tags: dict[str, str] = {}
         self.fifo_topic = "false"
         self.content_based_deduplication = "false"
 
@@ -101,7 +102,7 @@ class Topic(CloudFormationModel):
         self,
         message: str,
         subject: Optional[str] = None,
-        message_attributes: Optional[Dict[str, Any]] = None,
+        message_attributes: Optional[dict[str, Any]] = None,
         group_id: Optional[str] = None,
         deduplication_id: Optional[str] = None,
         message_structure: Optional[str] = None,
@@ -197,7 +198,7 @@ class Topic(CloudFormationModel):
 
     def _create_default_topic_policy(
         self, region_name: str, account_id: str, name: str
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         return {
             "Version": "2008-10-17",
             "Id": "__default_policy_ID",
@@ -231,7 +232,7 @@ class Subscription(BaseModel):
         self.endpoint = endpoint
         self.protocol = protocol
         self.arn = make_arn_for_subscription(self.topic.arn)
-        self.attributes: Dict[str, Any] = {}
+        self.attributes: dict[str, Any] = {}
         self._filter_policy = None  # filter policy as a dict, not json.
         self._filter_policy_matcher: Optional[FilterPolicyMatcher] = None
         self.confirmed = False
@@ -245,7 +246,7 @@ class Subscription(BaseModel):
         message: str,
         message_id: str,
         subject: Optional[str] = None,
-        message_attributes: Optional[Dict[str, Any]] = None,
+        message_attributes: Optional[dict[str, Any]] = None,
         group_id: Optional[str] = None,
         deduplication_id: Optional[str] = None,
         message_structure: Optional[str] = None,
@@ -284,15 +285,15 @@ class Subscription(BaseModel):
             else:
                 raw_message_attributes = {}
                 for key, value in message_attributes.items():  # type: ignore
-                    attr_type = "string_value"
+                    attr_type = "StringValue"
                     type_value = value["Value"]
                     if value["Type"].startswith("Binary"):
-                        attr_type = "binary_value"
+                        attr_type = "BinaryValue"
                     elif value["Type"].startswith("Number"):
                         type_value = str(value["Value"])
 
                     raw_message_attributes[key] = {
-                        "data_type": value["Type"],
+                        "DataType": value["Type"],
                         attr_type: type_value,
                     }
 
@@ -325,7 +326,7 @@ class Subscription(BaseModel):
                 qualifier = arr[-1]
                 function_name = arr[-2]
             else:
-                assert False
+                raise AssertionError()
 
             from moto.awslambda.utils import get_backend
 
@@ -338,8 +339,8 @@ class Subscription(BaseModel):
         message: str,
         message_id: str,
         subject: Optional[str],
-        message_attributes: Optional[Dict[str, Any]] = None,
-    ) -> Dict[str, Any]:
+        message_attributes: Optional[dict[str, Any]] = None,
+    ) -> dict[str, Any]:
         key = self.private_key()
         cert_subject = [NameAttribute(NameOID.COMMON_NAME, "sns.amazonaws.com")]
         issuer = [
@@ -393,7 +394,7 @@ Notification
             serialization.Encoding.PEM
         )
 
-        post_data: Dict[str, Any] = {
+        post_data: dict[str, Any] = {
             "Type": "Notification",
             "MessageId": message_id,
             "TopicArn": self.topic.arn,
@@ -410,7 +411,7 @@ Notification
             post_data["MessageAttributes"] = message_attributes
         return post_data
 
-    @lru_cache()
+    @lru_cache
     def private_key(self) -> rsa.RSAPrivateKey:
         return rsa.generate_private_key(public_exponent=65537, key_size=2048)
 
@@ -439,7 +440,7 @@ class PlatformApplication(BaseModel):
         region: str,
         name: str,
         platform: str,
-        attributes: Dict[str, str],
+        attributes: dict[str, str],
     ):
         self.region = region
         self.name = name
@@ -456,7 +457,7 @@ class PlatformEndpoint(BaseModel):
         application: PlatformApplication,
         custom_user_data: str,
         token: str,
-        attributes: Dict[str, str],
+        attributes: dict[str, str],
     ):
         self.region = region
         self.application = application
@@ -465,7 +466,7 @@ class PlatformEndpoint(BaseModel):
         self.attributes = attributes
         self.id = mock_random.uuid4()
         self.arn = f"arn:{get_partition(region)}:sns:{region}:{account_id}:endpoint/{self.application.platform}/{self.application.name}/{self.id}"
-        self.messages: Dict[str, str] = OrderedDict()
+        self.messages: dict[str, str] = OrderedDict()
         self.__fixup_attributes()
 
     def __fixup_attributes(self) -> None:
@@ -513,16 +514,16 @@ class SNSBackend(BaseBackend):
 
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.topics: Dict[str, Topic] = OrderedDict()
+        self.topics: dict[str, Topic] = OrderedDict()
         self.subscriptions: OrderedDict[str, Subscription] = OrderedDict()
-        self.applications: Dict[str, PlatformApplication] = {}
-        self.platform_endpoints: Dict[str, PlatformEndpoint] = {}
+        self.applications: dict[str, PlatformApplication] = {}
+        self.platform_endpoints: dict[str, PlatformEndpoint] = {}
         self.region_name = region_name
-        self.sms_attributes: Dict[str, str] = {}
+        self.sms_attributes: dict[str, str] = {}
         # We're storing the messages twice here
         # The tuple is for backwards compatibility; the object is to expose this data to the MotoAPI
         # We should combine these in a next major release, when we're allowed to break compatibility
-        self.sms_messages: Dict[str, Tuple[str, str]] = OrderedDict()
+        self.sms_messages: dict[str, tuple[str, str]] = OrderedDict()
         self.sms_message_objects: dict[str, SMS] = {}
         self.opt_out_numbers = [
             "+447420500600",
@@ -535,22 +536,22 @@ class SNSBackend(BaseBackend):
             "+447700900907",
         ]
 
-        self._message_public_keys: Dict[str, bytes] = {}
+        self._message_public_keys: dict[str, bytes] = {}
 
-    def get_sms_attributes(self, filter_list: Set[str]) -> Dict[str, str]:
+    def get_sms_attributes(self, filter_list: set[str]) -> dict[str, str]:
         if len(filter_list) > 0:
             return {k: v for k, v in self.sms_attributes.items() if k in filter_list}
         else:
             return self.sms_attributes
 
-    def set_sms_attributes(self, attrs: Dict[str, str]) -> None:
+    def set_sms_attributes(self, attrs: dict[str, str]) -> None:
         self.sms_attributes.update(attrs)
 
     def create_topic(
         self,
         name: str,
-        attributes: Optional[Dict[str, str]] = None,
-        tags: Optional[Dict[str, str]] = None,
+        attributes: Optional[dict[str, str]] = None,
+        tags: Optional[dict[str, str]] = None,
     ) -> Topic:
         if attributes is None:
             attributes = {}
@@ -582,8 +583,8 @@ class SNSBackend(BaseBackend):
             return candidate_topic
 
     def _get_values_nexttoken(
-        self, values_map: Dict[str, Any], next_token: Optional[str] = None
-    ) -> Tuple[List[Any], Optional[int]]:
+        self, values_map: dict[str, Any], next_token: Optional[str] = None
+    ) -> tuple[list[Any], Optional[int]]:
         i_next_token = int(next_token or "0")
         values = list(values_map.values())[
             i_next_token : i_next_token + DEFAULT_PAGE_SIZE
@@ -594,12 +595,12 @@ class SNSBackend(BaseBackend):
             i_next_token = None  # type: ignore
         return values, i_next_token
 
-    def _get_topic_subscriptions(self, topic: Topic) -> List[Subscription]:
+    def _get_topic_subscriptions(self, topic: Topic) -> list[Subscription]:
         return [sub for sub in self.subscriptions.values() if sub.topic == topic]
 
     def list_topics(
         self, next_token: Optional[str] = None
-    ) -> Tuple[List[Topic], Optional[int]]:
+    ) -> tuple[list[Topic], Optional[int]]:
         return self._get_values_nexttoken(self.topics, next_token)
 
     def delete_topic_subscriptions(self, topic: Topic) -> None:
@@ -710,12 +711,12 @@ class SNSBackend(BaseBackend):
 
     def list_subscriptions(
         self, next_token: Optional[str] = None
-    ) -> Tuple[List[Subscription], Optional[int]]:
+    ) -> tuple[list[Subscription], Optional[int]]:
         return self._get_values_nexttoken(self.subscriptions, next_token)
 
     def list_subscriptions_by_topic(
         self, topic_arn: str, next_token: Optional[str] = None
-    ) -> Tuple[List[Subscription], Optional[int]]:
+    ) -> tuple[list[Subscription], Optional[int]]:
         topic = self.get_topic(topic_arn)
         filtered = OrderedDict(
             [(sub.arn, sub) for sub in self._get_topic_subscriptions(topic)]
@@ -728,7 +729,7 @@ class SNSBackend(BaseBackend):
         arn: Optional[str],
         phone_number: Optional[str] = None,
         subject: Optional[str] = None,
-        message_attributes: Optional[Dict[str, Any]] = None,
+        message_attributes: Optional[dict[str, Any]] = None,
         group_id: Optional[str] = None,
         deduplication_id: Optional[str] = None,
         message_structure: Optional[str] = None,
@@ -792,7 +793,7 @@ class SNSBackend(BaseBackend):
         return message_id
 
     def create_platform_application(
-        self, name: str, platform: str, attributes: Dict[str, str]
+        self, name: str, platform: str, attributes: dict[str, str]
     ) -> PlatformApplication:
         application = PlatformApplication(
             self.account_id, self.region_name, name, platform, attributes
@@ -807,7 +808,7 @@ class SNSBackend(BaseBackend):
             raise SNSNotFoundError("PlatformApplication does not exist")
 
     def set_platform_application_attributes(
-        self, arn: str, attributes: Dict[str, Any]
+        self, arn: str, attributes: dict[str, Any]
     ) -> PlatformApplication:
         application = self.get_application(arn)
         application.attributes.update(attributes)
@@ -827,7 +828,7 @@ class SNSBackend(BaseBackend):
         application: PlatformApplication,
         custom_user_data: str,
         token: str,
-        attributes: Dict[str, str],
+        attributes: dict[str, str],
     ) -> PlatformEndpoint:
         for endpoint in self.platform_endpoints.values():
             if token == endpoint.token:
@@ -855,7 +856,7 @@ class SNSBackend(BaseBackend):
 
     def list_endpoints_by_platform_application(
         self, application_arn: str
-    ) -> List[PlatformEndpoint]:
+    ) -> list[PlatformEndpoint]:
         return [
             endpoint
             for endpoint in self.platform_endpoints.values()
@@ -869,7 +870,7 @@ class SNSBackend(BaseBackend):
             raise SNSNotFoundError("Endpoint does not exist")
 
     def set_endpoint_attributes(
-        self, arn: str, attributes: Dict[str, Any]
+        self, arn: str, attributes: dict[str, Any]
     ) -> PlatformEndpoint:
         endpoint = self.get_endpoint(arn)
         if "Enabled" in attributes:
@@ -883,7 +884,7 @@ class SNSBackend(BaseBackend):
         except KeyError:
             pass  # idempotent operation
 
-    def get_subscription_attributes(self, arn: str) -> Dict[str, Any]:
+    def get_subscription_attributes(self, arn: str) -> dict[str, Any]:
         subscription = self.subscriptions.get(arn)
 
         if not subscription:
@@ -938,8 +939,8 @@ class SNSBackend(BaseBackend):
         combinations = 1
 
         def aggregate_rules(
-            filter_policy: Dict[str, Any], depth: int = 1
-        ) -> List[List[Any]]:
+            filter_policy: dict[str, Any], depth: int = 1
+        ) -> list[list[Any]]:
             """
             This method evaluate the filter policy recursively, and returns only a list of lists of rules.
             It also calculates the combinations of rules, calculated depending on the nesting of the rules.
@@ -1113,8 +1114,8 @@ class SNSBackend(BaseBackend):
         region_name: str,
         topic_arn: str,
         label: str,
-        aws_account_ids: List[str],
-        action_names: List[str],
+        aws_account_ids: list[str],
+        action_names: list[str],
     ) -> None:
         topic = self.get_topic(topic_arn)
         policy = topic._policy_json
@@ -1158,13 +1159,13 @@ class SNSBackend(BaseBackend):
 
         topic._policy_json["Statement"] = statements
 
-    def list_tags_for_resource(self, resource_arn: str) -> Dict[str, str]:
+    def list_tags_for_resource(self, resource_arn: str) -> dict[str, str]:
         if resource_arn not in self.topics:
             raise ResourceNotFoundError
 
         return self.topics[resource_arn]._tags
 
-    def tag_resource(self, resource_arn: str, tags: Dict[str, str]) -> None:
+    def tag_resource(self, resource_arn: str, tags: dict[str, str]) -> None:
         if resource_arn not in self.topics:
             raise ResourceNotFoundError
 
@@ -1176,7 +1177,7 @@ class SNSBackend(BaseBackend):
 
         self.topics[resource_arn]._tags = updated_tags
 
-    def untag_resource(self, resource_arn: str, tag_keys: List[str]) -> None:
+    def untag_resource(self, resource_arn: str, tag_keys: list[str]) -> None:
         if resource_arn not in self.topics:
             raise ResourceNotFoundError
 
@@ -1184,8 +1185,8 @@ class SNSBackend(BaseBackend):
             self.topics[resource_arn]._tags.pop(key, None)
 
     def publish_batch(
-        self, topic_arn: str, publish_batch_request_entries: List[Dict[str, Any]]
-    ) -> Tuple[List[Dict[str, str]], List[Dict[str, Any]]]:
+        self, topic_arn: str, publish_batch_request_entries: list[dict[str, Any]]
+    ) -> tuple[list[dict[str, str]], list[dict[str, Any]]]:
         """
         The MessageDeduplicationId-parameter has not yet been implemented.
         """
@@ -1201,14 +1202,14 @@ class SNSBackend(BaseBackend):
         fifo_topic = topic.fifo_topic == "true"
         if fifo_topic:
             if not all(
-                ["MessageGroupId" in entry for entry in publish_batch_request_entries]
+                "MessageGroupId" in entry for entry in publish_batch_request_entries
             ):
                 raise SNSInvalidParameter(
                     "Invalid parameter: The MessageGroupId parameter is required for FIFO topics"
                 )
 
-        successful: List[Dict[str, str]] = []
-        failed: List[Dict[str, Any]] = []
+        successful: list[dict[str, str]] = []
+        failed: list[dict[str, Any]] = []
 
         for entry in publish_batch_request_entries:
             try:
@@ -1240,7 +1241,7 @@ class SNSBackend(BaseBackend):
         """
         return number.endswith("99")
 
-    def list_phone_numbers_opted_out(self) -> List[str]:
+    def list_phone_numbers_opted_out(self) -> list[str]:
         return self.opt_out_numbers
 
     def opt_in_phone_number(self, number: str) -> None:
@@ -1252,9 +1253,9 @@ class SNSBackend(BaseBackend):
     @paginate(pagination_model=PAGINATION_MODEL)  # type: ignore[misc]
     def list_config_service_resources(  # type: ignore[misc]
         self,
-        resource_ids: Optional[List[str]] = None,
+        resource_ids: Optional[list[str]] = None,
         resource_name: Optional[str] = None,
-    ) -> List[Dict[str, Any]]:
+    ) -> list[dict[str, Any]]:
         """List SNS topics for AWS Config."""
         topics = list(self.topics.values())
 
@@ -1277,7 +1278,7 @@ class SNSBackend(BaseBackend):
 
         return config_resources
 
-    def get_config_resource(self, resource_id: str) -> Optional[Dict[str, Any]]:
+    def get_config_resource(self, resource_id: str) -> Optional[dict[str, Any]]:
         """Get a specific SNS topic configuration for AWS Config."""
         if resource_id not in self.topics:
             return None
@@ -1313,7 +1314,7 @@ class SNSBackend(BaseBackend):
             },
             "configurationItemMD5Hash": "",
         }
-        configuration = cast(Dict[str, Any], config_item["configuration"])
+        configuration = cast(dict[str, Any], config_item["configuration"])
 
         if topic.kms_master_key_id:
             configuration["kmsMasterKeyId"] = topic.kms_master_key_id
@@ -1329,11 +1330,11 @@ class SNSBackend(BaseBackend):
     def confirm_subscription(self) -> None:
         pass
 
-    def get_endpoint_attributes(self, arn: str) -> Dict[str, str]:
+    def get_endpoint_attributes(self, arn: str) -> dict[str, str]:
         endpoint = self.get_endpoint(arn)
         return endpoint.attributes
 
-    def get_platform_application_attributes(self, arn: str) -> Dict[str, str]:
+    def get_platform_application_attributes(self, arn: str) -> dict[str, str]:
         application = self.get_application(arn)
         return application.attributes
 
