@@ -1,9 +1,6 @@
 import boto3
 
-from moto import mock_ec2
 
-
-@mock_ec2
 def setup_networking(region_name="us-east-1"):
     ec2 = boto3.resource("ec2", region_name=region_name)
     vpc = ec2.create_vpc(CidrBlock="10.11.0.0/16")
@@ -16,7 +13,6 @@ def setup_networking(region_name="us-east-1"):
     return {"vpc": vpc.id, "subnet1": subnet1.id, "subnet2": subnet2.id}
 
 
-@mock_ec2
 def setup_instance_with_networking(image_id, instance_type):
     mock_data = setup_networking()
     ec2 = boto3.resource("ec2", region_name="us-east-1")
