@@ -1,36 +1,14 @@
-import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_dynamodb
+from moto import mock_aws
 
 
-def _create_user_table():
-    client = boto3.client("dynamodb", region_name="us-east-1")
-    client.create_table(
-        TableName="users",
-        KeySchema=[{"AttributeName": "username", "KeyType": "HASH"}],
-        AttributeDefinitions=[{"AttributeName": "username", "AttributeType": "S"}],
-        ProvisionedThroughput={"ReadCapacityUnits": 5, "WriteCapacityUnits": 5},
-    )
-    client.put_item(
-        TableName="users", Item={"username": {"S": "user1"}, "binaryfoo": {"B": b"bar"}}
-    )
-    client.put_item(
-        TableName="users", Item={"username": {"S": "user2"}, "foo": {"S": "bar"}}
-    )
-    client.put_item(
-        TableName="users", Item={"username": {"S": "user3"}, "foo": {"S": "bar"}}
-    )
-    return client
-
-
-@mock_dynamodb
-def test_batch_items_returns_all():
-    dynamodb = _create_user_table()
-    returned_items = dynamodb.batch_get_item(
+@mock_aws
+def test_batch_items_returns_all(ddb_client, user_table):
+    returned_items = ddb_client.batch_get_item(
         RequestItems={
-            "users": {
+            user_table.name: {
                 "Keys": [
                     {"username": {"S": "user0"}},
                     {"username": {"S": "user1"}},
@@ -40,20 +18,22 @@ def test_batch_items_returns_all():
                 "ConsistentRead": True,
             }
         }
-    )["Responses"]["users"]
+    )["Responses"][user_table.name]
     assert len(returned_items) == 3
     assert {"username": {"S": "user1"}, "binaryfoo": {"B": b"bar"}} in returned_items
     assert {"username": {"S": "user2"}, "foo": {"S": "bar"}} in returned_items
     assert {"username": {"S": "user3"}, "foo": {"S": "bar"}} in returned_items
 
 
-@mock_dynamodb
-def test_batch_items_throws_exception_when_requesting_100_items_for_single_table():
-    dynamodb = _create_user_table()
+@mock_aws
+def test_batch_items_throws_exception_when_requesting_100_items_for_single_table(
+    ddb_client,
+    user_table,
+):
     with pytest.raises(ClientError) as ex:
-        dynamodb.batch_get_item(
+        ddb_client.batch_get_item(
             RequestItems={
-                "users": {
+                user_table.name: {
                     "Keys": [
                         {"username": {"S": "user" + str(i)}} for i in range(0, 104)
                     ],
@@ -65,17 +45,18 @@ def test_batch_items_throws_exception_when_requesting_100_items_for_single_table
     msg = ex.value.response["Error"]["Message"]
     assert (
         msg
-        == "1 validation error detected: Value at 'requestItems.users.member.keys' failed to satisfy constraint: Member must have length less than or equal to 100"
+        == f"1 validation error detected: Value at 'requestItems.{user_table.name}.member.keys' failed to satisfy constraint: Member must have length less than or equal to 100"
     )
 
 
-@mock_dynamodb
-def test_batch_items_throws_exception_when_requesting_100_items_across_all_tables():
-    dynamodb = _create_user_table()
+@mock_aws
+def test_batch_items_throws_exception_when_requesting_100_items_across_all_tables(
+    ddb_client, user_table
+):
     with pytest.raises(ClientError) as ex:
-        dynamodb.batch_get_item(
+        ddb_client.batch_get_item(
             RequestItems={
-                "users": {
+                user_table.name: {
                     "Keys": [
                         {"username": {"S": "user" + str(i)}} for i in range(0, 75)
                     ],
@@ -94,26 +75,25 @@ def test_batch_items_throws_exception_when_requesting_100_items_across_all_table
     assert err["Message"] == "Too many items requested for the BatchGetItem call"
 
 
-@mock_dynamodb
-def test_batch_items_with_basic_projection_expression():
-    dynamodb = _create_user_table()
-    returned_items = dynamodb.batch_get_item(
+@mock_aws
+def test_batch_items_with_basic_projection_expression(ddb_resource, user_table):
+    returned_items = ddb_resource.batch_get_item(
         RequestItems={
-            "users": {
+            user_table.name: {
                 "Keys": [
-                    {"username": {"S": "user0"}},
-                    {"username": {"S": "user1"}},
-                    {"username": {"S": "user2"}},
-                    {"username": {"S": "user3"}},
+                    {"username": "user0"},
+                    {"username": "user1"},
+                    {"username": "user2"},
+                    {"username": "user3"},
                 ],
                 "ConsistentRead": True,
                 "ProjectionExpression": "username",
             }
         }
-    )["Responses"]["users"]
+    )["Responses"][user_table.name]
 
     assert len(returned_items) == 3
-    assert [item["username"]["S"] for item in returned_items] == [
+    assert [item["username"] for item in returned_items] == [
         "user1",
         "user2",
         "user3",
@@ -121,32 +101,33 @@ def test_batch_items_with_basic_projection_expression():
     assert [item.get("foo") for item in returned_items] == [None, None, None]
 
     # The projection expression should not remove data from storage
-    returned_items = dynamodb.batch_get_item(
+    returned_items = ddb_resource.batch_get_item(
         RequestItems={
-            "users": {
+            user_table.name: {
                 "Keys": [
-                    {"username": {"S": "user0"}},
-                    {"username": {"S": "user1"}},
-                    {"username": {"S": "user2"}},
-                    {"username": {"S": "user3"}},
+                    {"username": "user0"},
+                    {"username": "user1"},
+                    {"username": "user2"},
+                    {"username": "user3"},
                 ],
                 "ConsistentRead": True,
             }
         }
-    )["Responses"]["users"]
+    )["Responses"][user_table.name]
 
     assert len(returned_items) == 3
-    assert {"username": {"S": "user1"}, "binaryfoo": {"B": b"bar"}} in returned_items
-    assert {"username": {"S": "user2"}, "foo": {"S": "bar"}} in returned_items
-    assert {"username": {"S": "user3"}, "foo": {"S": "bar"}} in returned_items
+    assert {"username": "user1", "binaryfoo": b"bar"} in returned_items
+    assert {"username": "user2", "foo": "bar"} in returned_items
+    assert {"username": "user3", "foo": "bar"} in returned_items
 
 
-@mock_dynamodb
-def test_batch_items_with_basic_projection_expression_and_attr_expression_names():
-    dynamodb = _create_user_table()
-    returned_items = dynamodb.batch_get_item(
+@mock_aws
+def test_batch_items_with_basic_projection_expression_and_attr_expression_names(
+    ddb_client, user_table
+):
+    returned_items = ddb_client.batch_get_item(
         RequestItems={
-            "users": {
+            user_table.name: {
                 "Keys": [
                     {"username": {"S": "user0"}},
                     {"username": {"S": "user1"}},
@@ -158,7 +139,7 @@ def test_batch_items_with_basic_projection_expression_and_attr_expression_names(
                 "ExpressionAttributeNames": {"#rl": "username"},
             }
         }
-    )["Responses"]["users"]
+    )["Responses"][user_table.name]
 
     assert len(returned_items) == 3
     assert {"username": {"S": "user1"}} in returned_items
@@ -166,13 +147,14 @@ def test_batch_items_with_basic_projection_expression_and_attr_expression_names(
     assert {"username": {"S": "user3"}} in returned_items
 
 
-@mock_dynamodb
-def test_batch_items_should_throw_exception_for_duplicate_request():
-    client = _create_user_table()
+@mock_aws
+def test_batch_items_should_throw_exception_for_duplicate_request(
+    ddb_client, user_table
+):
     with pytest.raises(ClientError) as ex:
-        client.batch_get_item(
+        ddb_client.batch_get_item(
             RequestItems={
-                "users": {
+                user_table.name: {
                     "Keys": [
                         {"username": {"S": "user0"}},
                         {"username": {"S": "user0"}},
@@ -186,8 +168,8 @@ def test_batch_items_should_throw_exception_for_duplicate_request():
     assert err["Message"] == "Provided list of item keys contains duplicates"
 
 
-@mock_dynamodb
-def test_batch_items_should_return_16mb_max():
+@mock_aws
+def test_batch_items_should_return_16mb_max(ddb_client, user_table):
     """
     A single operation can retrieve up to 16 MB of data [...]. BatchGetItem returns a partial result if the response size limit is exceeded [..].
 
@@ -197,25 +179,24 @@ def test_batch_items_should_return_16mb_max():
     It also returns an appropriate UnprocessedKeys value so you can get the next page of results.
     If desired, your application can include its own logic to assemble the pages of results into one dataset.
     """
-    client = _create_user_table()
     # Fill table with all the data
     for i in range(100):
-        client.put_item(
-            TableName="users",
+        ddb_client.put_item(
+            TableName=user_table.name,
             Item={"username": {"S": f"largedata{i}"}, "foo": {"S": "x" * 300000}},
         )
 
-    resp = client.batch_get_item(
+    resp = ddb_client.batch_get_item(
         RequestItems={
-            "users": {
+            user_table.name: {
                 "Keys": [{"username": {"S": f"largedata{i}"}} for i in range(75)],
                 "ConsistentRead": True,
             }
         }
     )
 
-    assert len(resp["Responses"]["users"]) == 55
-    unprocessed_keys = resp["UnprocessedKeys"]["users"]["Keys"]
+    assert len(resp["Responses"][user_table.name]) == 55
+    unprocessed_keys = resp["UnprocessedKeys"][user_table.name]["Keys"]
     # 75 requested, 55 returned --> 20 unprocessed
     assert len(unprocessed_keys) == 20
 
