@@ -1,4 +1,7 @@
-from moto import mock_ec2, mock_elbv2
+import pytest
+from botocore.exceptions import ClientError
+
+from moto import mock_aws
 
 from .test_elbv2 import create_load_balancer
 
@@ -9,8 +12,7 @@ default_action = {
 }
 
 
-@mock_elbv2
-@mock_ec2
+@mock_aws
 def test_create_listener_rule_with_tags():
     response, _, _, _, _, elbv2 = create_load_balancer()
 
@@ -36,8 +38,7 @@ def test_create_listener_rule_with_tags():
     assert tags == {"k1": "v1"}
 
 
-@mock_elbv2
-@mock_ec2
+@mock_aws
 def test_listener_rule_add_remove_tags():
     response, _, _, _, _, elbv2 = create_load_balancer()
 
@@ -85,3 +86,35 @@ def test_listener_rule_add_remove_tags():
         {"Key": "b", "Value": "b"},
         {"Key": "c", "Value": "b"},
     ]
+
+
+@mock_aws
+def test_remove_tags_to_invalid_listener_rule():
+    response, _, _, _, _, elbv2 = create_load_balancer()
+    load_balancer_arn = response.get("LoadBalancers")[0].get("LoadBalancerArn")
+
+    listener_arn = elbv2.create_listener(
+        LoadBalancerArn=load_balancer_arn,
+        Protocol="HTTP",
+        Port=80,
+        DefaultActions=[],
+    )["Listeners"][0]["ListenerArn"]
+    rule_arn = elbv2.create_rule(
+        ListenerArn=listener_arn,
+        Priority=100,
+        Conditions=[create_condition],
+        Actions=[default_action],
+        Tags=[{"Key": "k1", "Value": "v1"}],
+    )["Rules"][0]["RuleArn"]
+
+    # add a random string in the ARN to make the resource non-existent
+    BAD_ARN = rule_arn + "randostring"
+
+    # test for exceptions on remove tags
+    with pytest.raises(ClientError) as err:
+        elbv2.remove_tags(ResourceArns=[BAD_ARN], TagKeys=["a"])
+
+    assert err.value.response["Error"]["Code"] == "RuleNotFound"
+    assert (
+        err.value.response["Error"]["Message"] == "The specified rule does not exist."
+    )
