@@ -1,17 +1,18 @@
 """Unit tests for lakeformation-supported APIs."""
-from typing import Dict, Optional
+
+from typing import Optional
 
 import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_lakeformation
+from moto import mock_aws
 
 # See our Development Tips on writing tests for hints on how to write good tests:
 # http://docs.getmoto.org/en/latest/docs/contributing/development_tips/tests.html
 
 
-@mock_lakeformation
+@mock_aws
 def test_register_resource():
     client = boto3.client("lakeformation", region_name="us-east-2")
     resp = client.register_resource(ResourceArn="some arn", RoleArn="another arn")
@@ -22,7 +23,7 @@ def test_register_resource():
         client.register_resource(ResourceArn="some arn", RoleArn="another arn")
 
 
-@mock_lakeformation
+@mock_aws
 def test_describe_resource():
     client = boto3.client("lakeformation", region_name="us-east-2")
     client.register_resource(ResourceArn="some arn", RoleArn="role arn")
@@ -32,7 +33,7 @@ def test_describe_resource():
     assert resp["ResourceInfo"] == {"ResourceArn": "some arn", "RoleArn": "role arn"}
 
 
-@mock_lakeformation
+@mock_aws
 def test_deregister_resource():
     client = boto3.client("lakeformation", region_name="us-east-2")
     client.register_resource(ResourceArn="some arn")
@@ -49,7 +50,7 @@ def test_deregister_resource():
     assert err["Code"] == "EntityNotFoundException"
 
 
-@mock_lakeformation
+@mock_aws
 def test_list_resources():
     client = boto3.client("lakeformation", region_name="us-east-2")
 
@@ -63,7 +64,7 @@ def test_list_resources():
     assert len(resp["ResourceInfoList"]) == 2
 
 
-@mock_lakeformation
+@mock_aws
 def test_data_lake_settings():
     client = boto3.client("lakeformation", region_name="us-east-2")
     resp = client.get_data_lake_settings()
@@ -93,7 +94,7 @@ def test_data_lake_settings():
     assert resp["DataLakeSettings"] == settings
 
 
-@mock_lakeformation
+@mock_aws
 def test_grant_permissions():
     client = boto3.client("lakeformation", region_name="us-east-2")
 
@@ -115,7 +116,7 @@ def test_grant_permissions():
     ]
 
 
-@mock_lakeformation
+@mock_aws
 def test_grant_permissions_idempotent():
     client = boto3.client("lakeformation", region_name="us-east-2")
 
@@ -138,7 +139,7 @@ def test_grant_permissions_idempotent():
     ]
 
 
-@mock_lakeformation
+@mock_aws
 def test_grant_permissions_staggered():
     client = boto3.client("lakeformation", region_name="us-east-2")
     client.grant_permissions(
@@ -154,12 +155,13 @@ def test_grant_permissions_staggered():
 
     resp = client.list_permissions()
     assert len(resp["PrincipalResourcePermissions"]) == 1
-    assert set(resp["PrincipalResourcePermissions"][0]["Permissions"]) == set(
-        ["DESCRIBE", "CREATE_TABLE"]
-    )
+    assert set(resp["PrincipalResourcePermissions"][0]["Permissions"]) == {
+        "DESCRIBE",
+        "CREATE_TABLE",
+    }
 
 
-@mock_lakeformation
+@mock_aws
 def test_list_permissions():
     client = boto3.client("lakeformation", region_name="eu-west-2")
 
@@ -185,7 +187,7 @@ def test_list_permissions():
     ]
 
 
-@mock_lakeformation
+@mock_aws
 def test_list_permissions_invalid_input():
     client = boto3.client("lakeformation", region_name="eu-west-2")
 
@@ -256,7 +258,7 @@ def grant_data_location_permissions(
     )
 
 
-def db_response(principal: str, catalog_id: str, db: str) -> Dict:
+def db_response(principal: str, catalog_id: str, db: str) -> dict:
     return {
         "Principal": {"DataLakePrincipalIdentifier": principal},
         "Resource": {
@@ -270,7 +272,7 @@ def db_response(principal: str, catalog_id: str, db: str) -> Dict:
     }
 
 
-def table_response(principal: str, catalog_id: str, db: str, table: str) -> Dict:
+def table_response(principal: str, catalog_id: str, db: str, table: str) -> dict:
     return {
         "Principal": {"DataLakePrincipalIdentifier": principal},
         "Resource": {
@@ -286,7 +288,7 @@ def table_response(principal: str, catalog_id: str, db: str, table: str) -> Dict
     }
 
 
-def catalog_response(principal: str) -> Dict:
+def catalog_response(principal: str) -> dict:
     return {
         "Principal": {"DataLakePrincipalIdentifier": principal},
         "Resource": {"Catalog": {}},
@@ -297,7 +299,7 @@ def catalog_response(principal: str) -> Dict:
 
 def data_location_response(
     principal: str, resource_arn: str, catalog_id: Optional[str] = None
-) -> Dict:
+) -> dict:
     response = {
         "Principal": {"DataLakePrincipalIdentifier": principal},
         "Resource": {"DataLocation": {"ResourceArn": resource_arn}},
@@ -309,7 +311,7 @@ def data_location_response(
     return response
 
 
-@mock_lakeformation
+@mock_aws
 def test_list_permissions_filtered_for_catalog_id():
     client = boto3.client("lakeformation", region_name="eu-west-2")
     catalog_id_1 = "000000000000"
@@ -335,7 +337,7 @@ def test_list_permissions_filtered_for_catalog_id():
     assert permissions == [catalog_response(principal=principal_2)]
 
 
-@mock_lakeformation
+@mock_aws
 def test_list_permissions_filtered_for_resource_type():
     client = boto3.client("lakeformation", region_name="eu-west-2")
     catalog_id = "000000000000"
@@ -375,7 +377,7 @@ def test_list_permissions_filtered_for_resource_type():
     ]
 
 
-@mock_lakeformation
+@mock_aws
 def test_list_permissions_filtered_for_resource_db():
     client = boto3.client("lakeformation", region_name="eu-west-2")
     catalog_id = "000000000000"
@@ -406,7 +408,7 @@ def test_list_permissions_filtered_for_resource_db():
     ]
 
 
-@mock_lakeformation
+@mock_aws
 def test_list_permissions_filtered_for_resource_table():
     client = boto3.client("lakeformation", region_name="eu-west-2")
     catalog_id = "000000000000"
@@ -453,7 +455,7 @@ def test_list_permissions_filtered_for_resource_table():
     ]
 
 
-@mock_lakeformation
+@mock_aws
 def test_list_permissions_filtered_for_resource_data_location():
     client = boto3.client("lakeformation", region_name="eu-west-2")
     catalog_id = "000000000000"
@@ -492,7 +494,7 @@ def test_list_permissions_filtered_for_resource_data_location():
     ]
 
 
-@mock_lakeformation
+@mock_aws
 def test_revoke_permissions():
     client = boto3.client("lakeformation", region_name="eu-west-2")
 
@@ -521,20 +523,19 @@ def test_revoke_permissions():
         "Database": {"Name": "db"}
     }
     # compare as sets to be order independent
-    assert set(resp["PrincipalResourcePermissions"][0]["Permissions"]) == set(
-        ["SELECT", "ALTER"]
-    )
+    assert set(resp["PrincipalResourcePermissions"][0]["Permissions"]) == {
+        "SELECT",
+        "ALTER",
+    }
     assert set(
         resp["PrincipalResourcePermissions"][0]["PermissionsWithGrantOption"]
-    ) == set(
-        [
-            "SELECT",
-            "DROP",
-        ]
-    )
+    ) == {
+        "SELECT",
+        "DROP",
+    }
 
 
-@mock_lakeformation
+@mock_aws
 def test_revoke_permissions_unknown_catalog_id():
     client = boto3.client("lakeformation", region_name="eu-west-2")
 
@@ -559,7 +560,7 @@ def test_revoke_permissions_unknown_catalog_id():
     assert len(["PrincipalResourcePermissions"]) == 1
 
 
-@mock_lakeformation
+@mock_aws
 def test_list_data_cells_filter():
     client = boto3.client("lakeformation", region_name="eu-west-2")
 
@@ -567,7 +568,7 @@ def test_list_data_cells_filter():
     assert resp["DataCellsFilters"] == []
 
 
-@mock_lakeformation
+@mock_aws
 def test_batch_revoke_permissions():
     client = boto3.client("lakeformation", region_name="eu-west-2")
 
