@@ -2,16 +2,16 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_managedblockchain
+from moto import mock_aws
 
 from . import helpers
 
 
-@mock_managedblockchain
+@mock_aws
 def test_create_network():
     conn = boto3.client("managedblockchain", region_name="us-east-1")
 
-    response = conn.create_network(
+    create = conn.create_network(
         Name="testnetwork1",
         Framework="HYPERLEDGER_FABRIC",
         FrameworkVersion="1.2",
@@ -19,8 +19,8 @@ def test_create_network():
         VotingPolicy=helpers.default_votingpolicy,
         MemberConfiguration=helpers.default_memberconfiguration,
     )
-    network_id = response["NetworkId"]
-    member_id = response["MemberId"]
+    network_id = create["NetworkId"]
+    member_id = create["MemberId"]
     assert network_id.startswith("n-")
     assert len(network_id) == 28
     assert member_id.startswith("m-")
@@ -32,11 +32,20 @@ def test_create_network():
     assert mbcnetworks[0]["Name"] == "testnetwork1"
 
     # Get network details
-    response = conn.get_network(NetworkId=network_id)
-    assert response["Network"]["Name"] == "testnetwork1"
+    get_network = conn.get_network(NetworkId=network_id)["Network"]
+    assert get_network["Name"] == "testnetwork1"
+    assert get_network["Framework"] == "HYPERLEDGER_FABRIC"
+    assert get_network["FrameworkVersion"] == "1.2"
+    assert get_network["FrameworkAttributes"] == {
+        "Fabric": {
+            "Edition": "STARTER",
+            "OrderingServiceEndpoint": f"orderer.{network_id.lower()}.managedblockchain.us-east-1.amazonaws.com:30001",
+        }
+    }
+    assert get_network["VotingPolicy"] == helpers.default_votingpolicy
 
 
-@mock_managedblockchain
+@mock_aws
 def test_create_network_with_description():
     conn = boto3.client("managedblockchain", region_name="us-east-1")
 
@@ -61,7 +70,7 @@ def test_create_network_with_description():
     assert response["Network"]["Description"] == "Test Network 1"
 
 
-@mock_managedblockchain
+@mock_aws
 def test_create_network_noframework():
     conn = boto3.client("managedblockchain", region_name="us-east-1")
 
@@ -80,7 +89,7 @@ def test_create_network_noframework():
     assert "Invalid request body" in err["Message"]
 
 
-@mock_managedblockchain
+@mock_aws
 def test_create_network_badframeworkver():
     conn = boto3.client("managedblockchain", region_name="us-east-1")
 
@@ -102,7 +111,7 @@ def test_create_network_badframeworkver():
     )
 
 
-@mock_managedblockchain
+@mock_aws
 def test_create_network_badedition():
     conn = boto3.client("managedblockchain", region_name="us-east-1")
 
@@ -123,7 +132,7 @@ def test_create_network_badedition():
     assert "Invalid request body" in err["Message"]
 
 
-@mock_managedblockchain
+@mock_aws
 def test_get_network_badnetwork():
     conn = boto3.client("managedblockchain", region_name="us-east-1")
 
