@@ -749,11 +749,12 @@ def test_untag_resource():
     assert resp["Tags"] == []
 
 
-def set_transition(transition={"progression": "immediate"}):
+def set_transition(transition=None):
+    transition = transition or {"progression": "immediate"}
     if settings.TEST_DECORATOR_MODE:
         state_manager.set_transition(model_name="osis::pipeline", transition=transition)
     else:
-        post_body = dict(model_name="osis::pipeline", transition=transition)
+        post_body = {"model_name": "osis::pipeline", "transition": transition}
         requests.post(
             "http://localhost:5000/moto-api/state-manager/set-transition",
             data=json.dumps(post_body),
