@@ -5,16 +5,16 @@ import pytest
 from botocore.exceptions import ClientError
 from freezegun import freeze_time
 
-from moto import mock_swf, settings
+from moto import mock_aws, settings
 
-from ..utils import SCHEDULE_ACTIVITY_TASK_DECISION, setup_workflow_boto3
+from ..utils import SCHEDULE_ACTIVITY_TASK_DECISION, setup_workflow
 
 # PollForActivityTask endpoint
 
 
-@mock_swf
-def test_poll_for_activity_task_when_one_boto3():
-    client = setup_workflow_boto3()
+@mock_aws
+def test_poll_for_activity_task_when_one():
+    client = setup_workflow()
     decision_token = client.poll_for_decision_task(
         domain="test-domain", taskList={"name": "queue"}
     )["taskToken"]
@@ -41,9 +41,9 @@ def test_poll_for_activity_task_when_one_boto3():
 
 
 @pytest.mark.parametrize("task_name", ["activity-task-list", "non-existent-queue"])
-@mock_swf
-def test_poll_for_activity_task_when_none_boto3(task_name):
-    client = setup_workflow_boto3()
+@mock_aws
+def test_poll_for_activity_task_when_none(task_name):
+    client = setup_workflow()
     resp = client.poll_for_decision_task(
         domain="test-domain", taskList={"name": task_name}
     )
@@ -58,9 +58,9 @@ def test_poll_for_activity_task_when_none_boto3(task_name):
 @pytest.mark.parametrize(
     "task_name,cnt", [("activity-task-list", 1), ("non-existent", 0)]
 )
-@mock_swf
-def test_count_pending_activity_tasks_boto3(task_name, cnt):
-    client = setup_workflow_boto3()
+@mock_aws
+def test_count_pending_activity_tasks(task_name, cnt):
+    client = setup_workflow()
     decision_token = client.poll_for_decision_task(
         domain="test-domain", taskList={"name": "queue"}
     )["taskToken"]
@@ -78,9 +78,9 @@ def test_count_pending_activity_tasks_boto3(task_name, cnt):
 # RespondActivityTaskCompleted endpoint
 
 
-@mock_swf
-def test_respond_activity_task_completed_boto3():
-    client = setup_workflow_boto3()
+@mock_aws
+def test_respond_activity_task_completed():
+    client = setup_workflow()
     decision_token = client.poll_for_decision_task(
         domain="test-domain", taskList={"name": "queue"}
     )["taskToken"]
@@ -107,9 +107,9 @@ def test_respond_activity_task_completed_boto3():
     }
 
 
-@mock_swf
-def test_respond_activity_task_completed_on_closed_workflow_execution_boto3():
-    client = setup_workflow_boto3()
+@mock_aws
+def test_respond_activity_task_completed_on_closed_workflow_execution():
+    client = setup_workflow()
     decision_token = client.poll_for_decision_task(
         domain="test-domain", taskList={"name": "queue"}
     )["taskToken"]
@@ -131,9 +131,9 @@ def test_respond_activity_task_completed_on_closed_workflow_execution_boto3():
     assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
 
 
-@mock_swf
-def test_respond_activity_task_completed_with_task_already_completed_boto3():
-    client = setup_workflow_boto3()
+@mock_aws
+def test_respond_activity_task_completed_with_task_already_completed():
+    client = setup_workflow()
     decision_token = client.poll_for_decision_task(
         domain="test-domain", taskList={"name": "queue"}
     )["taskToken"]
@@ -158,9 +158,9 @@ def test_respond_activity_task_completed_with_task_already_completed_boto3():
 # RespondActivityTaskFailed endpoint
 
 
-@mock_swf
-def test_respond_activity_task_failed_boto3():
-    client = setup_workflow_boto3()
+@mock_aws
+def test_respond_activity_task_failed():
+    client = setup_workflow()
     decision_token = client.poll_for_decision_task(
         domain="test-domain", taskList={"name": "queue"}
     )["taskToken"]
@@ -188,12 +188,12 @@ def test_respond_activity_task_failed_boto3():
     }
 
 
-@mock_swf
-def test_respond_activity_task_completed_with_wrong_token_boto3():
+@mock_aws
+def test_respond_activity_task_completed_with_wrong_token():
     # NB: we just test ONE failure case for RespondActivityTaskFailed
     # because the safeguards are shared with RespondActivityTaskCompleted, so
     # no need to retest everything end-to-end.
-    client = setup_workflow_boto3()
+    client = setup_workflow()
     decision_token = client.poll_for_decision_task(
         domain="test-domain", taskList={"name": "queue"}
     )["taskToken"]
@@ -214,9 +214,9 @@ def test_respond_activity_task_completed_with_wrong_token_boto3():
 # RecordActivityTaskHeartbeat endpoint
 
 
-@mock_swf
-def test_record_activity_task_heartbeat_boto3():
-    client = setup_workflow_boto3()
+@mock_aws
+def test_record_activity_task_heartbeat():
+    client = setup_workflow()
     decision_token = client.poll_for_decision_task(
         domain="test-domain", taskList={"name": "queue"}
     )["taskToken"]
@@ -231,9 +231,9 @@ def test_record_activity_task_heartbeat_boto3():
     assert resp["cancelRequested"] is False
 
 
-@mock_swf
-def test_record_activity_task_heartbeat_with_wrong_token_boto3():
-    client = setup_workflow_boto3()
+@mock_aws
+def test_record_activity_task_heartbeat_with_wrong_token():
+    client = setup_workflow()
     decision_token = client.poll_for_decision_task(
         domain="test-domain", taskList={"name": "queue"}
     )["taskToken"]
@@ -251,11 +251,11 @@ def test_record_activity_task_heartbeat_with_wrong_token_boto3():
     assert ex.value.response["ResponseMetadata"]["HTTPStatusCode"] == 400
 
 
-@mock_swf
-def test_record_activity_task_heartbeat_sets_details_in_case_of_timeout_boto3():
+@mock_aws
+def test_record_activity_task_heartbeat_sets_details_in_case_of_timeout():
     if settings.TEST_SERVER_MODE:
         raise SkipTest("Unable to manipulate time in ServerMode")
-    client = setup_workflow_boto3()
+    client = setup_workflow()
     decision_token = client.poll_for_decision_task(
         domain="test-domain", taskList={"name": "queue"}
     )["taskToken"]
